import setuptools

setuptools.setup(
    author="Giulio Cesare Mastrocinque Santo",
    name='HDSIdent',
    author_email="giuliosanto@gmail.com",
    url='https://github.com/GiulioCMSanto/HDSIdent',
    version='0.0.2.2',
    description='HDSIdent is an open-source Python package that can be used to obtain historical data segments suitable for performing System Identification',
    license="MIT",
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
    install_requires=["scikit-learn","scipy",
                      "pandas","numpy","matplotlib",
                      "seaborn","joblib","sympy"],
    zip_safe=True
)


from .data_treatment.data_preprocessing import Preprocessing
from .initial_intervals.bandpass_filter import BandpassFilter
from .initial_intervals.exponentially_weighted import ExponentiallyWeighted
from .initial_intervals.non_parametric_pettitt import PettittMethod
from .initial_intervals.sliding_window import SlidingWindow
from .model_structures.ar_structure import ARStructure
from .model_structures.arx_structure import ARXStructure
from .model_structures.laguerre_filter import LaguerreStructure
from .segmentation_methods.mimo_segmentation import MIMOSegmentation
from .segmentation_methods.statistical_segmentation import MIMOStatistical
